# Last edited on 2017-04-10 16:25:59 by stolfilocal

# Common part of Makefile for PDFLatex and old DVI LaTeX.
# Caller must define ${JOBNAME}

ifneq "/${JOBNAME}" "/"

PDF_FILE = ${JOBNAME}.pdf

PAPERSIZE = letter

PREVDIR   := NONE

TEMP_FILES = *.dvi *.log *.toc *.tof *.aux *.blg *.lof *.lot *.bbl

SUBDIRS = tables figures

SHOWPDF := evince

all: ${PDF_FILE}

PARTS := \
  ${wildcard [0-9][0-9][0-9]-*.tex}

MACROS := \
  ${wildcard macros-*.tex} \
  setpagedims.sty \
  stolfi-url.sty
  
BIBS := \
  ${wildcard *.bib}


######################################################################
# Compare with previous version:

ifneq "/${PREVDIR}" "/NONE"

DIFFS := ${subst .tex,.diff ${JOBNAME}.tex ${PARTS} ${MACROS}} 

compare: ${DIFFS}

%.diff: %.tex ${PREVDIR}/%.tex
	diff -Bb $*.tex ${PREVDIR}/$*.tex \
          | prettify-diff-output \
          > $*.diff

${JOBNAME}.diff ${PARTS} ${JOBNAME}.tex

else
compare: 
	@ echo "No previous version to compare against"
endif
#
######################################################################

clean:
	@for i in . ${SUBDIRS} ; do \
	  ( \
            if (test -d $$i) ; then \
              cd $$i ; \
              echo "Cleaning $$i" ; \
              rm -f ${TEMP_FILES} ${PDF_FILE} ; \
	    fi \
          ) \
	done

endif
