#! /bin/bash
# Last edited on 2010-05-03 20:31:09 by stolfilocal

# Usage:
#   $0 -resource { time | memory } -methods {METHOD}.. -datasets ${DATASET}..

methods=()
nmt=0
datasets=()
nds=0
cur="???"
resource="???"
while [[ $# -gt 0 ]] ; do 
  if [[ "/$1" == "/-methods" ]]; then
    cur="m"; shift
  elif [[ "/$1" == "/-datasets" ]]; then
    cur="d"; shift
  elif [[ ( $# -ge 2 ) && ( "/$1" == "/-resource" ) ]]; then
    resource="$2"; shift; shift
  elif [[ "/$1" =~ "^/-" ]]; then
    echo "** unknown option \"$1\"" 1>&2; exit 1
  else
    if [[ "/${cur}" == "/m" ]]; then 
      methods[$nmt]="$1"; nmt=$(( ${nmt} + 1 )); shift
    elif [[ "/${cur}" == "/d" ]]; then 
      datasets[$nds]="$1"; nds=$(( ${nds} + 1 )); shift
    else
      echo "** missing \"-methods\" or \"-datasets\"" 1>&2; exit 1
    fi
  fi
done

printf '%% Created by $0 -- DO NOT EDIT BY HAND, edits will be lost\n' 

# Print table preamble
printf '\\begin{tabular}{|r|' 
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  printf '|'
  imt=0
  while [[ ${imt} -lt ${nmt} ]]; do 
    printf 'r|'
    imt=$(( ${imt} + 1 ))
  done
  ids=$(( ${ids} + 1 ))
done
printf '}\n'

printf '  \\hline\n' 

# Print header 1
printf '  %23s' '~'
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  dsname="${datasets[$ids]}"
  printf ' & \\mcol{%d}{c||}{\\texttt{%s}}' "${nmt}" "${dsname}"
  ids=$(( ${ids} + 1 ))
done
printf ' \\\\\n'

printf '  \\hline\n' 

# Print header 2
printf '  %23s' '$N$'
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  imt=0
  while [[ ${imt} -lt ${nmt} ]]; do 
    mt="${methods[$imt]}"
    mtname=${mt%.*}
    mttag=${mt#*.}
    printf ' & %8s' "${mttag}"    
    # echo "mtname = ${mtname}  mttag = ${mttag}  dsname = ${dsname}" 1>&2;
    imt=$(( ${imt} + 1 ))
  done
  ids=$(( ${ids} + 1 ))
done
printf ' \\\\\n'

printf '  \\hline\n' 

# Print data
      
sizes=( 64 90 128 180 256 360 512 )
for sz in ${sizes[@]}; do  
  N=$(( ${sz} * ${sz} ))
  printf '  $%3s\\times%3s = %6d$' "${sz}" "${sz}" "${N}"
  ids=0;
  while [[ ${ids} -lt ${nds} ]]; do 
    dsname="${datasets[${ids}]}"
    imt=0
    while [[ ${imt} -lt ${nmt} ]]; do 
      mt="${methods[${imt}]}"
      mtname=${mt%.*}
      mttag=${mt#*.}
      # echo "sz = ${sz} dsname = ${dsname}  mtname = ${mtname}  mttag = ${mttag}" 1>&2;
      datafile="data/${dsname}-${mtname}-${sz}-CST.txt"
      if [[ -s ${datafile} ]]; then
        data=( `cat ${datafile}` )
        if [[ "/${data[0]}" != "/${N}" ]]; then
          echo '** inconsistent size "'"${data[0]}"'" "'"${N}"'"' 1>&2; exit 1
        fi
        T="${data[1]}"
        nnzA="${data[2]}"
        nnzL="${data[3]}"
        nnzU="${data[4]}"
      else
        echo '** missing file "'"${datafile}"'"' 1>&2;
        T="???"
        nnzA="???"
        nnzU="???"
      fi
      # echo "sz = ${sz} dsname = ${dsname}  mtname = ${mtname}  mttag = ${mttag}  T = ${T}  nnzA=${nnzA}  nnzU = ${nnzU}" 1>&2;
      if [[ "/${T}" == "/???" ]]; then
        val="???"
        fmt="%8s"
      elif [[ "/${resource}" == "/time" ]]; then
        val="${T}"
        fmt='%8.2f'
	echo "AQUI ${val} ${T}"
      elif [[ "/${resource}" == "/memory" ]]; then
        if [[ "/${mtname}" =~ "^/mscl" ]]; then
          val=$(( 65 * ${N} ))
        else
          val=$(( ( 12 * ${nnzA} ) + ( 16 * ${nnzU} ) ))
        fi
        val=`echo "${val}/1000000.0" | bc -lq`
        fmt='%8.1f'
      else
        echo '** unknown resource "'"${resource}"'"' 1>&2; exit 1
      fi
      val=`printf "${fmt}" "${val}"`
      echo "sz = ${sz} dsname = ${dsname}  mtname = ${mtname}  mttag = ${mttag}  T = ${T}  nnzA=${nnzA}  nnzU = ${nnzU}  val = ${val}" 1>&2;
      printf ' & %8s' "${val}"
      imt=$(( ${imt} + 1 ))
    done
    ids=$(( ${ids} + 1 ))
  done
  printf ' \\\\\n'
done

printf '  \\hline\n'

# Print table postamble
printf '\\end{tabular}\n'
